Index: /trunk/about.php
===================================================================
--- /trunk/about.php	(revision 28586)
+++ /trunk/about.php	(revision 28587)
@@ -38,5 +38,5 @@
 $page['body_id'] = 'theAboutPage';
 
-trigger_action('loc_begin_about');
+trigger_notify('loc_begin_about');
 
 $template->set_filename('about', 'about.tpl');
Index: /trunk/admin.php
===================================================================
--- /trunk/admin.php	(revision 28586)
+++ /trunk/admin.php	(revision 28587)
@@ -34,5 +34,5 @@
 include_once(PHPWG_ROOT_PATH.'admin/include/add_core_tabs.inc.php');
 
-trigger_action('loc_begin_admin');
+trigger_notify('loc_begin_admin');
 
 // +-----------------------------------------------------------------------+
@@ -245,5 +245,5 @@
 // +-----------------------------------------------------------------------+
 
-$plugin_menu_links = trigger_event('get_admin_plugin_menu_links', array() );
+$plugin_menu_links = trigger_change('get_admin_plugin_menu_links', array() );
 
 function UC_name_compare($a, $b)
@@ -285,5 +285,5 @@
 // +-----------------------------------------------------------------------+
 
-trigger_action('loc_begin_admin_page');
+trigger_notify('loc_begin_admin_page');
 include(PHPWG_ROOT_PATH.'admin/'.$page['page'].'.php');
 
@@ -299,5 +299,5 @@
 include(PHPWG_ROOT_PATH.'include/page_header.php');
 
-trigger_action('loc_end_admin');
+trigger_notify('loc_end_admin');
 
 flush_page_messages();
Index: /trunk/admin/album_notification.php
===================================================================
--- /trunk/admin/album_notification.php	(revision 28586)
+++ /trunk/admin/album_notification.php	(revision 28587)
@@ -84,5 +84,5 @@
     $_POST['group'],
     array(
-      'subject' => l10n('[%s] Visit album %s', $conf['gallery_title'], trigger_event('render_category_name', $category['name'], 'admin_cat_list')),
+      'subject' => l10n('[%s] Visit album %s', $conf['gallery_title'], trigger_change('render_category_name', $category['name'], 'admin_cat_list')),
       // TODO : change this language variable to 'Visit album %s'
       // TODO : 'language_selected' => ....
@@ -92,9 +92,9 @@
       'assign' => array(
         'IMG_URL' => $img_url,
-        'CAT_NAME' => trigger_event('render_category_name', $category['name'], 'admin_cat_list'),
+        'CAT_NAME' => trigger_change('render_category_name', $category['name'], 'admin_cat_list'),
         'LINK' => make_index_url(array(
             'category' => array(
               'id' => $category['id'],
-              'name' => trigger_event('render_category_name', $category['name'], 'admin_cat_list'),
+              'name' => trigger_change('render_category_name', $category['name'], 'admin_cat_list'),
               'permalink' => $category['permalink']
               )
Index: /trunk/admin/batch_manager.php
===================================================================
--- /trunk/admin/batch_manager.php	(revision 28586)
+++ /trunk/admin/batch_manager.php	(revision 28587)
@@ -302,5 +302,5 @@
   }
 
-  $filter_sets = trigger_event('perform_batch_manager_prefilters', $filter_sets, $_SESSION['bulk_manager_filter']['prefilter']);
+  $filter_sets = trigger_change('perform_batch_manager_prefilters', $filter_sets, $_SESSION['bulk_manager_filter']['prefilter']);
 }
 
Index: /trunk/admin/batch_manager_global.php
===================================================================
--- /trunk/admin/batch_manager_global.php	(revision 28586)
+++ /trunk/admin/batch_manager_global.php	(revision 28587)
@@ -41,5 +41,5 @@
 check_status(ACCESS_ADMINISTRATOR);
 
-trigger_action('loc_begin_element_set_global');
+trigger_notify('loc_begin_element_set_global');
 
 check_input_parameter('del_tags', $_POST, true, PATTERN_ID);
@@ -405,5 +405,5 @@
   }
 
-  trigger_action('element_set_global_action', $action, $collection);
+  trigger_notify('element_set_global_action', $action, $collection);
 }
 
@@ -430,5 +430,5 @@
 }
 
-$prefilters = trigger_event('get_batch_manager_prefilters', $prefilters);
+$prefilters = trigger_change('get_batch_manager_prefilters', $prefilters);
 usort($prefilters, 'UC_name_compare');
 
@@ -675,5 +675,5 @@
   ));
 
-trigger_action('loc_end_element_set_global');
+trigger_notify('loc_end_element_set_global');
 
 //----------------------------------------------------------- sending html code
Index: /trunk/admin/batch_manager_unit.php
===================================================================
--- /trunk/admin/batch_manager_unit.php	(revision 28586)
+++ /trunk/admin/batch_manager_unit.php	(revision 28587)
@@ -40,5 +40,5 @@
 check_status(ACCESS_ADMINISTRATOR);
 
-trigger_action('loc_begin_element_set_unit');
+trigger_notify('loc_begin_element_set_unit');
 
 // +-----------------------------------------------------------------------+
@@ -255,5 +255,5 @@
 }
 
-trigger_action('loc_end_element_set_unit');
+trigger_notify('loc_end_element_set_unit');
 
 // +-----------------------------------------------------------------------+
Index: /trunk/admin/cat_list.php
===================================================================
--- /trunk/admin/cat_list.php	(revision 28586)
+++ /trunk/admin/cat_list.php	(revision 28587)
@@ -34,5 +34,5 @@
 check_status(ACCESS_ADMINISTRATOR);
 
-trigger_action('loc_begin_cat_list');
+trigger_notify('loc_begin_cat_list');
 
 if (!empty($_POST) or isset($_GET['delete']))
@@ -325,5 +325,5 @@
     array(
       'NAME'       => 
-        trigger_event(
+        trigger_change(
           'render_category_name',
           $category['name'],
@@ -364,5 +364,5 @@
 }
 
-trigger_action('loc_end_cat_list');
+trigger_notify('loc_end_cat_list');
 
 // +-----------------------------------------------------------------------+
Index: /trunk/admin/cat_modify.php
===================================================================
--- /trunk/admin/cat_modify.php	(revision 28586)
+++ /trunk/admin/cat_modify.php	(revision 28587)
@@ -104,5 +104,5 @@
 check_status(ACCESS_ADMINISTRATOR);
 
-trigger_action('loc_begin_cat_modify');
+trigger_notify('loc_begin_cat_modify');
 
 //---------------------------------------------------------------- verification
@@ -369,5 +369,5 @@
 }
 
-trigger_action('loc_end_cat_modify');
+trigger_notify('loc_end_cat_modify');
 
 //----------------------------------------------------------- sending html code
Index: /trunk/admin/comments.php
===================================================================
--- /trunk/admin/comments.php	(revision 28586)
+++ /trunk/admin/comments.php	(revision 28587)
@@ -201,7 +201,7 @@
       'ID' => $row['id'],
       'TN_SRC' => $thumb,
-      'AUTHOR' => trigger_event('render_comment_author', $author_name),
+      'AUTHOR' => trigger_change('render_comment_author', $author_name),
       'DATE' => format_date($row['date'], true),
-      'CONTENT' => trigger_event('render_comment_content',$row['content']),
+      'CONTENT' => trigger_change('render_comment_content',$row['content']),
       'IS_PENDING' => ('false' == $row['validated']),
       )
Index: /trunk/admin/help.php
===================================================================
--- /trunk/admin/help.php	(revision 28586)
+++ /trunk/admin/help.php	(revision 28587)
@@ -47,5 +47,5 @@
 $tabsheet->assign();
 
-trigger_action('loc_end_help');
+trigger_notify('loc_end_help');
 
 $template->set_filenames(array('help' => 'help.tpl'));
Index: /trunk/admin/history.php
===================================================================
--- /trunk/admin/history.php	(revision 28586)
+++ /trunk/admin/history.php	(revision 28587)
@@ -217,5 +217,5 @@
 
   /*TODO - no need to get a huge number of rows from db (should take only what needed for display + SQL_CALC_FOUND_ROWS*/
-  $data = trigger_event('get_history', array(), $page['search'], $types);
+  $data = trigger_change('get_history', array(), $page['search'], $types);
   usort($data, 'history_compare');
 
@@ -317,5 +317,5 @@
     while ($row=pwg_db_fetch_assoc($result))
     {
-      $name_of_tag[ $row['id'] ] = '<a href="'.make_index_url( array('tags'=>array($row))).'">'.trigger_event("render_tag_name", $row['name'], $row).'</a>';
+      $name_of_tag[ $row['id'] ] = '<a href="'.make_index_url( array('tags'=>array($row))).'">'.trigger_change("render_tag_name", $row['name'], $row).'</a>';
     }
   }
@@ -409,5 +409,5 @@
       if (isset($image_infos[$line['image_id']]['label']))
       {
-        $image_title.= ' '.trigger_event('render_element_description', $image_infos[$line['image_id']]['label']);
+        $image_title.= ' '.trigger_change('render_element_description', $image_infos[$line['image_id']]['label']);
       }
       else
Index: /trunk/admin/include/check_integrity.class.php
===================================================================
--- /trunk/admin/include/check_integrity.class.php	(revision 28586)
+++ /trunk/admin/include/check_integrity.class.php	(revision 28587)
@@ -67,5 +67,5 @@
     $this->build_ignore_list = array();
 
-    trigger_action('list_check_integrity', $this);
+    trigger_notify('list_check_integrity', $this);
 
     // Information
Index: /trunk/admin/include/functions.php
===================================================================
--- /trunk/admin/include/functions.php	(revision 28586)
+++ /trunk/admin/include/functions.php	(revision 28587)
@@ -163,5 +163,5 @@
   pwg_query($query);
 
-  trigger_action('delete_categories', $ids);
+  trigger_notify('delete_categories', $ids);
 }
 
@@ -251,5 +251,5 @@
     return 0;
   }
-  trigger_action('begin_delete_elements', $ids);
+  trigger_notify('begin_delete_elements', $ids);
 
   if ($physical_deletion)
@@ -326,5 +326,5 @@
   }
 
-  trigger_action('delete_elements', $ids);
+  trigger_notify('delete_elements', $ids);
   return count($ids);
 }
@@ -384,5 +384,5 @@
   pwg_query($query);
 
-  trigger_action('delete_user', $user_id);
+  trigger_notify('delete_user', $user_id);
 }
 
@@ -1574,5 +1574,5 @@
     if (count($existing_tags = array_from_query($query, 'id')) == 0)
     {
-      $url_name = trigger_event('render_tag_url', $tag_name);
+      $url_name = trigger_change('render_tag_url', $tag_name);
       // search existing by url name
       $query = '
@@ -1842,5 +1842,5 @@
     pwg_query($query);
   }
-  trigger_action('invalidate_user_cache', $full);
+  trigger_notify('invalidate_user_cache', $full);
 }
 
@@ -1977,5 +1977,5 @@
       array(
         'name' => $tag_name,
-        'url_name' => trigger_event('render_tag_url', $tag_name),
+        'url_name' => trigger_change('render_tag_url', $tag_name),
         )
       );
@@ -2327,5 +2327,5 @@
   {
     $raw_name = $row['name'];
-    $name = trigger_event('render_tag_name', $raw_name, $row);
+    $name = trigger_change('render_tag_name', $raw_name, $row);
 
     $taglist[] =  array(
@@ -2336,5 +2336,5 @@
     if (!$only_user_language)
     {
-      $alt_names = trigger_event('get_tag_alt_names', array(), $raw_name);
+      $alt_names = trigger_change('get_tag_alt_names', array(), $raw_name);
 
       foreach( array_diff( array_unique($alt_names), array($name) ) as $alt)
Index: /trunk/admin/include/functions_history.inc.php
===================================================================
--- /trunk/admin/include/functions_history.inc.php	(revision 28586)
+++ /trunk/admin/include/functions_history.inc.php	(revision 28587)
@@ -178,5 +178,5 @@
 
 add_event_handler('get_history', 'get_history', EVENT_HANDLER_PRIORITY_NEUTRAL, 3);
-trigger_action('functions_history_included');
+trigger_notify('functions_history_included');
 
 ?>
Index: /trunk/admin/include/image.class.php
===================================================================
--- /trunk/admin/include/image.class.php	(revision 28586)
+++ /trunk/admin/include/image.class.php	(revision 28587)
@@ -65,5 +65,5 @@
     $this->source_filepath = $source_filepath;
 
-    trigger_action('load_image_library', array(&$this) );
+    trigger_notify('load_image_library', array(&$this) );
 
     if (is_object($this->image))
Index: /trunk/admin/include/tabsheet.class.php
===================================================================
--- /trunk/admin/include/tabsheet.class.php	(revision 28586)
+++ /trunk/admin/include/tabsheet.class.php	(revision 28587)
@@ -89,5 +89,5 @@
   function select($name)
   {
-    $this->sheets = trigger_event('tabsheet_before_select', $this->sheets, $this->uniqid);
+    $this->sheets = trigger_change('tabsheet_before_select', $this->sheets, $this->uniqid);
     if (!array_key_exists($name, $this->sheets))
     {
Index: /trunk/admin/maintenance.php
===================================================================
--- /trunk/admin/maintenance.php	(revision 28586)
+++ /trunk/admin/maintenance.php	(revision 28587)
@@ -221,5 +221,5 @@
 
 //$advanced_features is array of array composed of CAPTION & URL
-$advanced_features = trigger_event(
+$advanced_features = trigger_change(
   'get_admin_advanced_features_links',
   $advanced_features
Index: /trunk/admin/notification_by_mail.php
===================================================================
--- /trunk/admin/notification_by_mail.php	(revision 28586)
+++ /trunk/admin/notification_by_mail.php	(revision 28587)
@@ -254,5 +254,5 @@
 
         $customize_mail_content = 
-          trigger_event('nbm_render_global_customize_mail_content', $customize_mail_content);
+          trigger_change('nbm_render_global_customize_mail_content', $customize_mail_content);
 
 
@@ -341,5 +341,5 @@
 
               $nbm_user_customize_mail_content = 
-                trigger_event('nbm_render_user_customize_mail_content',
+                trigger_change('nbm_render_user_customize_mail_content',
                   $customize_mail_content, $nbm_user);
               if (!empty($nbm_user_customize_mail_content))
@@ -483,5 +483,5 @@
 // +-----------------------------------------------------------------------+
 add_event_handler('nbm_render_global_customize_mail_content', 'render_global_customize_mail_content');
-trigger_action('nbm_event_handler_added');
+trigger_notify('nbm_event_handler_added');
 
 
Index: /trunk/admin/picture_modify.php
===================================================================
--- /trunk/admin/picture_modify.php	(revision 28586)
+++ /trunk/admin/picture_modify.php	(revision 28587)
@@ -416,5 +416,5 @@
   ));
 
-trigger_action('loc_end_picture_modify');
+trigger_notify('loc_end_picture_modify');
 
 //----------------------------------------------------------- sending html code
Index: /trunk/admin/popuphelp.php
===================================================================
--- /trunk/admin/popuphelp.php	(revision 28586)
+++ /trunk/admin/popuphelp.php	(revision 28587)
@@ -56,5 +56,5 @@
   }
 
-  $help_content = trigger_event(
+  $help_content = trigger_change(
     'get_popup_help_content', $help_content, $_GET['page']);
 }
Index: /trunk/admin/site_manager.php
===================================================================
--- /trunk/admin/site_manager.php	(revision 28586)
+++ /trunk/admin/site_manager.php	(revision 28587)
@@ -177,5 +177,5 @@
   //$plugin_links is array of array composed of U_HREF, U_HINT & U_CAPTION
   $plugin_links =
-    trigger_event('get_admins_site_links',
+    trigger_change('get_admins_site_links',
       $plugin_links, $row['id'], $is_remote);
   $tpl_var['plugin_links'] = $plugin_links;
Index: /trunk/admin/tags.php
===================================================================
--- /trunk/admin/tags.php	(revision 28586)
+++ /trunk/admin/tags.php	(revision 28587)
@@ -77,5 +77,5 @@
           'id' => $tag_id,
           'name' => addslashes($tag_name),
-          'url_name' => trigger_event('render_tag_url', $tag_name),
+          'url_name' => trigger_change('render_tag_url', $tag_name),
           );
       }
@@ -134,5 +134,5 @@
           array(
             'name' => $tag_name,
-            'url_name' => trigger_event('render_tag_url', $tag_name),
+            'url_name' => trigger_change('render_tag_url', $tag_name),
             )
           );
@@ -219,5 +219,5 @@
       while ($row = pwg_db_fetch_assoc($result))
       {
-        $name_of_tag[ $row['id'] ] = trigger_event('render_tag_name', $row['name'], $row);
+        $name_of_tag[ $row['id'] ] = trigger_change('render_tag_name', $row['name'], $row);
       }
 
@@ -359,5 +359,5 @@
 foreach ($orphan_tags as $tag)
 {
-  $orphan_tag_names[] = trigger_event('render_tag_name', $tag['name'], $tag);
+  $orphan_tag_names[] = trigger_change('render_tag_name', $tag['name'], $tag);
 }
 
@@ -394,10 +394,10 @@
 {
   $raw_name = $tag['name'];
-  $tag['name'] = trigger_event('render_tag_name', $raw_name, $tag);
+  $tag['name'] = trigger_change('render_tag_name', $raw_name, $tag);
   $tag['counter'] = intval(@$tag_counters[ $tag['id'] ]);
   $tag['U_VIEW'] = make_index_url(array('tags'=>array($tag)));
   $tag['U_EDIT'] = 'admin.php?page=batch_manager&amp;filter=tag-'.$tag['id'];
 
-  $alt_names = trigger_event('get_tag_alt_names', array(), $raw_name);
+  $alt_names = trigger_change('get_tag_alt_names', array(), $raw_name);
   $alt_names = array_diff( array_unique($alt_names), array($tag['name']) );
   if (count($alt_names))
Index: /trunk/admin/themes_installed.php
===================================================================
--- /trunk/admin/themes_installed.php	(revision 28586)
+++ /trunk/admin/themes_installed.php	(revision 28587)
@@ -173,5 +173,5 @@
   );
 
-trigger_action('loc_end_themes_installed');
+trigger_notify('loc_end_themes_installed');
 
 $template->set_filenames(array('themes' => 'themes_installed.tpl'));
Index: /trunk/comments.php
===================================================================
--- /trunk/comments.php	(revision 28586)
+++ /trunk/comments.php	(revision 28587)
@@ -90,5 +90,5 @@
   );
 
-trigger_action('loc_begin_comments');
+trigger_notify('loc_begin_comments');
 
 if (!empty($_GET['since']) && is_numeric($_GET['since']))
@@ -484,8 +484,8 @@
       'src_image' => $src_image,
       'ALT' => $name,
-      'AUTHOR' => trigger_event('render_comment_author', $comment['author']),
+      'AUTHOR' => trigger_change('render_comment_author', $comment['author']),
       'WEBSITE_URL' => $comment['website_url'],
       'DATE'=>format_date($comment['date'], true),
-      'CONTENT'=>trigger_event('render_comment_content',$comment['content']),
+      'CONTENT'=>trigger_change('render_comment_content',$comment['content']),
       );
 
@@ -544,5 +544,5 @@
 }
 
-$derivative_params = trigger_event('get_comments_derivative_params', ImageStdParams::get_by_type(IMG_THUMB) );
+$derivative_params = trigger_change('get_comments_derivative_params', ImageStdParams::get_by_type(IMG_THUMB) );
 $template->assign( 'derivative_params', $derivative_params );
 
@@ -558,5 +558,5 @@
 // +-----------------------------------------------------------------------+
 include(PHPWG_ROOT_PATH.'include/page_header.php');
-trigger_action('loc_end_comments');
+trigger_notify('loc_end_comments');
 flush_page_messages();
 $template->pparse('comments');
Index: /trunk/i.php
===================================================================
--- /trunk/i.php	(revision 28586)
+++ /trunk/i.php	(revision 28587)
@@ -32,5 +32,5 @@
 
 
-function trigger_action() {}
+function trigger_notify() {}
 function get_extension( $filename )
 {
Index: /trunk/identification.php
===================================================================
--- /trunk/identification.php	(revision 28586)
+++ /trunk/identification.php	(revision 28587)
@@ -31,5 +31,5 @@
 check_status(ACCESS_FREE);
 
-trigger_action('loc_begin_identification');
+trigger_notify('loc_begin_identification');
 
 //-------------------------------------------------------------- identification
@@ -107,5 +107,5 @@
 //----------------------------------------------------------- html code display
 include(PHPWG_ROOT_PATH.'include/page_header.php');
-trigger_action('loc_end_identification');
+trigger_notify('loc_end_identification');
 flush_page_messages();
 $template->pparse('identification');
Index: /trunk/include/block.class.php
===================================================================
--- /trunk/include/block.class.php	(revision 28586)
+++ /trunk/include/block.class.php	(revision 28587)
@@ -50,5 +50,5 @@
   public function load_registered_blocks()
   {
-    trigger_action('blockmanager_register_blocks', array($this));
+    trigger_notify('blockmanager_register_blocks', array($this));
   }
   
@@ -111,5 +111,5 @@
     }
     $this->sort_blocks();
-    trigger_action('blockmanager_prepare_display', array($this));
+    trigger_notify('blockmanager_prepare_display', array($this));
     $this->sort_blocks();
   }
@@ -192,5 +192,5 @@
 
     $template->set_filename('menubar', $file);
-    trigger_action('blockmanager_apply', array($this) );
+    trigger_notify('blockmanager_apply', array($this) );
 
     foreach ($this->display_blocks as $id=>$block)
Index: /trunk/include/category_cats.inc.php
===================================================================
--- /trunk/include/category_cats.inc.php	(revision 28586)
+++ /trunk/include/category_cats.inc.php	(revision 28587)
@@ -270,5 +270,5 @@
   $template->set_filename('index_category_thumbnails', 'mainpage_categories.tpl');
 
-  trigger_action('loc_begin_index_category_thumbnails', $categories);
+  trigger_notify('loc_begin_index_category_thumbnails', $categories);
 
   $tpl_thumbnails_var = array();
@@ -281,5 +281,5 @@
     }
 
-    $category['name'] = trigger_event(
+    $category['name'] = trigger_change(
         'render_category_name',
         $category['name'],
@@ -317,6 +317,6 @@
                                   ),
           'DESCRIPTION' =>
-            trigger_event('render_category_literal_description',
-              trigger_event('render_category_description',
+            trigger_change('render_category_literal_description',
+              trigger_change('render_category_description',
                 @$category['comment'],
                 'subcatify_category_description')),
@@ -368,6 +368,6 @@
     );
 
-  $derivative_params = trigger_event('get_index_album_derivative_params', ImageStdParams::get_by_type(IMG_THUMB) );
-  $tpl_thumbnails_var_selection = trigger_event('loc_end_index_category_thumbnails', $tpl_thumbnails_var_selection);
+  $derivative_params = trigger_change('get_index_album_derivative_params', ImageStdParams::get_by_type(IMG_THUMB) );
+  $tpl_thumbnails_var_selection = trigger_change('loc_end_index_category_thumbnails', $tpl_thumbnails_var_selection);
   $template->assign( array(
     'maxRequests' =>$conf['max_requests'],
Index: /trunk/include/category_default.inc.php
===================================================================
--- /trunk/include/category_default.inc.php	(revision 28586)
+++ /trunk/include/category_default.inc.php	(revision 28587)
@@ -36,5 +36,5 @@
   );
 
-$selection = trigger_event('loc_index_thumbnails_selection', $selection);
+$selection = trigger_change('loc_index_thumbnails_selection', $selection);
 
 if (count($selection) > 0)
@@ -92,5 +92,5 @@
 $template->set_filenames( array( 'index_thumbnails' => 'thumbnails.tpl',));
 
-trigger_action('loc_begin_index_thumbnails', $pictures);
+trigger_notify('loc_begin_index_thumbnails', $pictures);
 $tpl_thumbnails_var = array();
 
@@ -153,9 +153,9 @@
 
 $template->assign( array(
-  'derivative_params' => trigger_event('get_index_derivative_params', ImageStdParams::get_by_type( pwg_get_session_var('index_deriv', IMG_THUMB) ) ),
+  'derivative_params' => trigger_change('get_index_derivative_params', ImageStdParams::get_by_type( pwg_get_session_var('index_deriv', IMG_THUMB) ) ),
   'maxRequests' =>$conf['max_requests'],
   'SHOW_THUMBNAIL_CAPTION' =>$conf['show_thumbnail_caption'],
     ) );
-$tpl_thumbnails_var = trigger_event('loc_end_index_thumbnails', $tpl_thumbnails_var, $pictures);
+$tpl_thumbnails_var = trigger_change('loc_end_index_thumbnails', $tpl_thumbnails_var, $pictures);
 $template->assign('thumbnails', $tpl_thumbnails_var);
 
Index: /trunk/include/common.inc.php
===================================================================
--- /trunk/include/common.inc.php	(revision 28586)
+++ /trunk/include/common.inc.php	(revision 28587)
@@ -176,5 +176,5 @@
   load_language('admin.lang');
 }
-trigger_action('loading_lang');
+trigger_notify('loading_lang');
 load_language('lang', PHPWG_ROOT_PATH.PWG_LOCAL_DIR, array('no_fallback'=>true, 'local'=>true) );
 
@@ -273,4 +273,4 @@
   add_event_handler('get_src_image_url', 'get_src_image_url_protection_handler', EVENT_HANDLER_PRIORITY_NEUTRAL, 2 );
 }
-trigger_action('init');
+trigger_notify('init');
 ?>
Index: /trunk/include/derivative.inc.php
===================================================================
--- /trunk/include/derivative.inc.php	(revision 28586)
+++ /trunk/include/derivative.inc.php	(revision 28587)
@@ -68,5 +68,5 @@
     {
       $ext = strtolower($ext);
-      $this->rel_path = trigger_event('get_mimetype_location', get_themeconf('mime_icon_dir').$ext.'.png', $ext );
+      $this->rel_path = trigger_change('get_mimetype_location', get_themeconf('mime_icon_dir').$ext.'.png', $ext );
       $this->flags |= self::IS_MIMETYPE;
       if ( ($size=@getimagesize(PHPWG_ROOT_PATH.$this->rel_path)) === false)
@@ -135,5 +135,5 @@
     if ( !($this->flags & self::IS_MIMETYPE) )
     {
-      $url = trigger_event('get_src_image_url', $url, $this);
+      $url = trigger_change('get_src_image_url', $url, $this);
     }
     return embellish_url($url);
@@ -236,5 +236,5 @@
     }
     return embellish_url(
-        trigger_event('get_derivative_url',
+        trigger_change('get_derivative_url',
           get_root_url().$rel_url,
           $params, $src_image, $rel_url
@@ -406,5 +406,5 @@
     }
     return embellish_url(
-        trigger_event('get_derivative_url',
+        trigger_change('get_derivative_url',
           get_root_url().$this->rel_url,
           $this->params, $this->src_image, $this->rel_url
Index: /trunk/include/functions.inc.php
===================================================================
--- /trunk/include/functions.inc.php	(revision 28586)
+++ /trunk/include/functions.inc.php	(revision 28587)
@@ -424,5 +424,5 @@
   }
 
-  $do_log = trigger_event('pwg_log_allowed', $do_log, $image_id, $image_type);
+  $do_log = trigger_change('pwg_log_allowed', $do_log, $image_id, $image_type);
 
   if (!$do_log)
@@ -774,5 +774,5 @@
     $user = build_user( $conf['guest_id'], true);
     load_language('common.lang');
-    trigger_action('loading_lang');
+    trigger_notify('loading_lang');
     load_language('lang', PHPWG_ROOT_PATH.PWG_LOCAL_DIR, array('no_fallback'=>true, 'local'=>true) );
     $template = new Template(PHPWG_ROOT_PATH.'themes', get_default_theme());
@@ -871,5 +871,5 @@
 
   // plugins want remove some themes based on user status maybe?
-  $themes = trigger_event('get_pwg_themes', $themes);
+  $themes = trigger_change('get_pwg_themes', $themes);
 
   return $themes;
@@ -1113,5 +1113,5 @@
   list($email) = pwg_db_fetch_row(pwg_query($query));
 
-  $email = trigger_event('get_webmaster_mail_address', $email);
+  $email = trigger_change('get_webmaster_mail_address', $email);
 
   return $email;
@@ -1155,5 +1155,5 @@
   }
 
-  trigger_action('load_conf', $condition);
+  trigger_notify('load_conf', $condition);
 }
 
Index: /trunk/include/functions_category.inc.php
===================================================================
--- /trunk/include/functions_category.inc.php	(revision 28586)
+++ /trunk/include/functions_category.inc.php	(revision 28587)
@@ -109,5 +109,5 @@
   }
 
-  $where = trigger_event('get_categories_menu_sql_where',
+  $where = trigger_change('get_categories_menu_sql_where',
     $where, $user['expand'], $filter['enabled'] );
 
@@ -124,5 +124,5 @@
     $row = array_merge($row,
       array(
-        'NAME' => trigger_event(
+        'NAME' => trigger_change(
           'render_category_name',
           $row['name'],
@@ -231,5 +231,5 @@
   global $conf, $page;
 
-  return trigger_event('get_category_preferred_image_orders', array(
+  return trigger_change('get_category_preferred_image_orders', array(
     array(l10n('Default'),                        '',                     true),
     array(l10n('Photo title, A &rarr; Z'),        'name ASC',             true),
@@ -280,5 +280,5 @@
       $option.= '- ';
       $option.= strip_tags(
-        trigger_event(
+        trigger_change(
           'render_category_name',
           $category['name'],
Index: /trunk/include/functions_mail.inc.php
===================================================================
--- /trunk/include/functions_mail.inc.php	(revision 28586)
+++ /trunk/include/functions_mail.inc.php	(revision 28587)
@@ -313,5 +313,5 @@
     }
     
-    trigger_action('loading_lang');
+    trigger_notify('loading_lang');
     load_language('lang', PHPWG_ROOT_PATH.PWG_LOCAL_DIR,
       array('language'=>$language, 'no_fallback'=>true, 'local'=>true)
@@ -697,5 +697,5 @@
       {
         $conf_mail[$cache_key]['theme'] = get_mail_template($content_type);
-        trigger_action('before_parse_mail_template', $cache_key, $content_type);
+        trigger_notify('before_parse_mail_template', $cache_key, $content_type);
       }
       $template = &$conf_mail[$cache_key]['theme'];
@@ -855,5 +855,5 @@
 
   $ret = true;
-  $pre_result = trigger_event('before_send_mail', true, $to, $args, $mail);
+  $pre_result = trigger_change('before_send_mail', true, $to, $args, $mail);
 
   if ($pre_result)
@@ -946,5 +946,5 @@
 }
 
-trigger_action('functions_mail_included');
+trigger_notify('functions_mail_included');
 
 ?>
Index: /trunk/include/functions_metadata.inc.php
===================================================================
--- /trunk/include/functions_metadata.inc.php	(revision 28586)
+++ /trunk/include/functions_metadata.inc.php	(revision 28587)
@@ -105,5 +105,5 @@
     // apparently mac uses some MacRoman crap encoding. I don't know
     // how to detect it so a plugin should do the trick.
-    $value = trigger_event('clean_iptc_value', $value);
+    $value = trigger_change('clean_iptc_value', $value);
     if ( ($qual = qualify_utf8($value)) != 0)
     {// has non ascii chars
@@ -153,5 +153,5 @@
   if ($exif = @read_exif_data($filename))
   {
-    $exif = trigger_event('format_exif_data', $exif, $filename, $map);
+    $exif = trigger_change('format_exif_data', $exif, $filename, $map);
 
     // configured fields
Index: /trunk/include/functions_plugins.inc.php
===================================================================
--- /trunk/include/functions_plugins.inc.php	(revision 28586)
+++ /trunk/include/functions_plugins.inc.php	(revision 28587)
@@ -247,5 +247,4 @@
  *
  * @since 2.6
- * @todo remove trigger_event()
  *
  * @param string $event
@@ -256,19 +255,9 @@
 function trigger_change($event, $data=null)
 {
-  $args = func_get_args();
-  return call_user_func_array('trigger_event', $args);
-}
-
-/**
- * @deprecated 2.6
- * @see trigger_change
- */
-function trigger_event($event, $data=null)
-{
   global $pwg_event_handlers;
 
   if (isset($pwg_event_handlers['trigger']))
   {// debugging
-    trigger_action('trigger',
+    trigger_notify('trigger',
       array('type'=>'event', 'event'=>$event, 'data'=>$data)
       );
@@ -299,5 +288,5 @@
   if (isset($pwg_event_handlers['trigger']))
   {// debugging
-    trigger_action('trigger',
+    trigger_notify('trigger',
       array('type'=>'post_event', 'event'=>$event, 'data'=>$data)
       );
@@ -312,5 +301,4 @@
  *
  * @since 2.6
- * @todo remove trigger_action()
  *
  * @param string $event
@@ -319,19 +307,9 @@
 function trigger_notify($event)
 {
-  $args = func_get_args();
-  return call_user_func_array('trigger_action', $args);
-}
-
-/**
- * @deprecated 2.6
- * @see trigger_notify
- */
-function trigger_action($event)
-{
   global $pwg_event_handlers;
 
   if (isset($pwg_event_handlers['trigger']) and $event!='trigger')
   {// debugging - avoid recursive calls
-    trigger_action('trigger',
+    trigger_notify('trigger',
       array('type'=>'action', 'event'=>$event, 'data'=>null)
       );
@@ -456,5 +434,5 @@
       load_plugin($plugin);
     }
-    trigger_action('plugins_loaded');
+    trigger_notify('plugins_loaded');
   }
 }
Index: /trunk/include/functions_rate.inc.php
===================================================================
--- /trunk/include/functions_rate.inc.php	(revision 28586)
+++ /trunk/include/functions_rate.inc.php	(revision 28587)
@@ -137,5 +137,5 @@
 function update_rating_score($element_id = false)
 {
-  if ( ($alt_result = trigger_event('update_rating_score', false, $element_id)) !== false)
+  if ( ($alt_result = trigger_change('update_rating_score', false, $element_id)) !== false)
   {
     return $alt_result;
Index: /trunk/include/functions_search.inc.php
===================================================================
--- /trunk/include/functions_search.inc.php	(revision 28586)
+++ /trunk/include/functions_search.inc.php	(revision 28587)
@@ -929,5 +929,5 @@
       default:
         // allow plugins to have their own scope with columns added in db by themselves
-        $clauses = trigger_event('qsearch_get_images_sql_scopes', $clauses, $token, $expr);
+        $clauses = trigger_change('qsearch_get_images_sql_scopes', $clauses, $token, $expr);
         break;
     }
@@ -1020,5 +1020,5 @@
   foreach ( $all_tags as &$tag )
   {
-    $tag['name'] = trigger_event('render_tag_name', $tag['name'], $tag);
+    $tag['name'] = trigger_change('render_tag_name', $tag['name'], $tag);
   }
   $qsr->all_tags = $all_tags;
@@ -1152,5 +1152,5 @@
 
   // allow plugins to add their own scopes
-  $scopes = trigger_event('qsearch_get_scopes', $scopes);
+  $scopes = trigger_change('qsearch_get_scopes', $scopes);
   $expression = new QExpression($q, $scopes);
 
@@ -1177,5 +1177,5 @@
 
 
-  trigger_action('qsearch_expression_parsed', $expression);
+  trigger_notify('qsearch_expression_parsed', $expression);
 //var_export($expression);
 
@@ -1189,5 +1189,5 @@
 
   // allow plugins to evaluate their own scopes
-  trigger_action('qsearch_before_eval', $expression, $qsr);
+  trigger_notify('qsearch_before_eval', $expression, $qsr);
 
   $ids = qsearch_eval($expression, $qsr, $tmp, $search_results['qs']['unmatched_terms']);
Index: /trunk/include/functions_tag.inc.php
===================================================================
--- /trunk/include/functions_tag.inc.php	(revision 28586)
+++ /trunk/include/functions_tag.inc.php	(revision 28587)
@@ -90,5 +90,5 @@
     {
       $row['counter'] = $counter;
-      $row['name'] = trigger_event('render_tag_name', $row['name'], $row);
+      $row['name'] = trigger_change('render_tag_name', $row['name'], $row);
       $tags[] = $row;
     }
@@ -112,5 +112,5 @@
   while ($row = pwg_db_fetch_assoc($result))
   {
-    $row['name'] = trigger_event('render_tag_name', $row['name'], $row);
+    $row['name'] = trigger_change('render_tag_name', $row['name'], $row);
     $tags[] = $row;
   }
@@ -278,5 +278,5 @@
   while($row = pwg_db_fetch_assoc($result))
   {
-    $row['name'] = trigger_event('render_tag_name', $row['name'], $row);
+    $row['name'] = trigger_change('render_tag_name', $row['name'], $row);
     $tags[] = $row;
   }
Index: /trunk/include/functions_user.inc.php
===================================================================
--- /trunk/include/functions_user.inc.php	(revision 28586)
+++ /trunk/include/functions_user.inc.php	(revision 28587)
@@ -175,5 +175,5 @@
   }
 
-  $errors = trigger_event(
+  $errors = trigger_change(
     'register_user_check',
     $errors,
@@ -274,5 +274,5 @@
     }
 
-    trigger_action(
+    trigger_notify(
       'register_user',
       array(
@@ -960,5 +960,5 @@
 
   $user['id'] = $_SESSION['pwg_uid'];
-  trigger_action('user_login', $user['id']);
+  trigger_notify('user_login', $user['id']);
 }
 
@@ -985,5 +985,5 @@
       {
         log_user($cookie[0], true);
-        trigger_action('login_success', stripslashes($username));
+        trigger_notify('login_success', stripslashes($username));
         return true;
       }
@@ -1086,5 +1086,5 @@
 function try_log_user($username, $password, $remember_me)
 {
-  return trigger_event('try_log_user', false, $username, $password, $remember_me);
+  return trigger_change('try_log_user', false, $username, $password, $remember_me);
 }
 
@@ -1122,8 +1122,8 @@
   {
     log_user($row['id'], $remember_me);
-    trigger_action('login_success', stripslashes($username));
+    trigger_notify('login_success', stripslashes($username));
     return true;
   }
-  trigger_action('login_failure', stripslashes($username));
+  trigger_notify('login_failure', stripslashes($username));
   return false;
 }
@@ -1136,5 +1136,5 @@
   global $conf;
 
-  trigger_action('user_logout', @$_SESSION['pwg_uid']);
+  trigger_notify('user_logout', @$_SESSION['pwg_uid']);
 
   $_SESSION = array();
Index: /trunk/include/no_photo_yet.inc.php
===================================================================
--- /trunk/include/no_photo_yet.inc.php	(revision 28586)
+++ /trunk/include/no_photo_yet.inc.php	(revision 28587)
@@ -98,5 +98,5 @@
     }
 
-    trigger_action('loc_end_no_photo_yet');
+    trigger_notify('loc_end_no_photo_yet');
 
     $template->pparse('no_photo_yet');
Index: /trunk/include/page_header.php
===================================================================
--- /trunk/include/page_header.php	(revision 28586)
+++ /trunk/include/page_header.php	(revision 28587)
@@ -27,5 +27,5 @@
 $template->set_filenames(array('header'=>'header.tpl'));
 
-trigger_action('loc_begin_page_header');
+trigger_notify('loc_begin_page_header');
 
 $template->assign(
@@ -36,5 +36,5 @@
 
     'PAGE_BANNER' =>
-      trigger_event(
+      trigger_change(
         'render_page_banner',
         str_replace(
@@ -97,9 +97,9 @@
 }
 
-trigger_action('loc_end_page_header');
+trigger_notify('loc_end_page_header');
 
 header('Content-Type: text/html; charset='.get_pwg_charset());
 $template->parse('header');
 
-trigger_action('loc_after_page_header');
+trigger_notify('loc_after_page_header');
 ?>
Index: /trunk/include/page_tail.php
===================================================================
--- /trunk/include/page_tail.php	(revision 28586)
+++ /trunk/include/page_tail.php	(revision 28587)
@@ -23,5 +23,5 @@
 $template->set_filenames(array('tail'=>'footer.tpl'));
 
-trigger_action('loc_begin_page_tail');
+trigger_notify('loc_begin_page_tail');
 
 $template->assign(
@@ -77,5 +77,5 @@
 }
 
-trigger_action('loc_end_page_tail');
+trigger_notify('loc_end_page_tail');
 //
 // Generate the page
Index: /trunk/include/picture_comment.inc.php
===================================================================
--- /trunk/include/picture_comment.inc.php	(revision 28586)
+++ /trunk/include/picture_comment.inc.php	(revision 28587)
@@ -74,5 +74,5 @@
 
   // allow plugins to notify what's going on
-  trigger_action( 'user_comment_insertion',
+  trigger_notify( 'user_comment_insertion',
       array_merge($comm, array('action'=>$comment_action) )
     );
@@ -182,7 +182,7 @@
         array(
           'ID' => $row['id'],
-          'AUTHOR' => trigger_event('render_comment_author', $row['author']),
+          'AUTHOR' => trigger_change('render_comment_author', $row['author']),
           'DATE' => format_date($row['date'], true),
-          'CONTENT' => trigger_event('render_comment_content',$row['content']),
+          'CONTENT' => trigger_change('render_comment_content',$row['content']),
           'WEBSITE_URL' => $row['website_url'],
         );
Index: /trunk/include/section_init.inc.php
===================================================================
--- /trunk/include/section_init.inc.php	(revision 28586)
+++ /trunk/include/section_init.inc.php	(revision 28587)
@@ -232,5 +232,5 @@
       $page,
       array(
-        'comment' => trigger_event(
+        'comment' => trigger_change(
             'render_category_description',
             $page['category']['comment'],
@@ -638,4 +638,4 @@
 }
 
-trigger_action('loc_end_section_init');
+trigger_notify('loc_end_section_init');
 ?>
Index: /trunk/include/template.class.php
===================================================================
--- /trunk/include/template.class.php	(revision 28586)
+++ /trunk/include/template.class.php	(revision 28587)
@@ -522,5 +522,5 @@
         $href .= '?v' . ($combi->version ? $combi->version : PHPWG_VERSION);
       // trigger the event for eventual use of a cdn
-      $href = trigger_event('combined_css', $href, $combi);
+      $href = trigger_change('combined_css', $href, $combi);
       $content[] = '<link rel="stylesheet" type="text/css" href="'.$href.'">';
     }
@@ -879,5 +879,5 @@
     }
     // trigger the event for eventual use of a cdn
-    $ret = trigger_event('combined_script', $ret, $script);
+    $ret = trigger_change('combined_script', $ret, $script);
     return embellish_url($ret);
   }
@@ -1935,5 +1935,5 @@
       $handle = $this->type. '.' .$combinable->id;
       $template->set_filename($handle, realpath(PHPWG_ROOT_PATH.$combinable->path));
-      trigger_action( 'combinable_preparse', $template, $combinable, $this); //allow themes and plugins to set their own vars to template ...
+      trigger_notify( 'combinable_preparse', $template, $combinable, $this); //allow themes and plugins to set their own vars to template ...
       $content = $template->parse($handle, true);
 
@@ -1991,5 +1991,5 @@
       $css = CssMin::minify($css, array('Variables'=>false));
     }
-    $css = trigger_event('combined_css_postfilter', $css);
+    $css = trigger_change('combined_css_postfilter', $css);
     return $css;
   }
Index: /trunk/include/user.inc.php
===================================================================
--- /trunk/include/user.inc.php	(revision 28586)
+++ /trunk/include/user.inc.php	(revision 28587)
@@ -73,4 +73,4 @@
   get_browser_language($user['language']);
 }
-trigger_action('user_init', $user);
+trigger_notify('user_init', $user);
 ?>
Index: /trunk/include/ws_core.inc.php
===================================================================
--- /trunk/include/ws_core.inc.php	(revision 28586)
+++ /trunk/include/ws_core.inc.php	(revision 28587)
@@ -292,5 +292,5 @@
         );
 
-    trigger_action('ws_add_methods', array(&$this) );
+    trigger_notify('ws_add_methods', array(&$this) );
     uksort( $this->_methods, 'strnatcmp' );
     $this->_requestHandler->handleRequest($this);
@@ -307,5 +307,5 @@
     @header('Content-Type: '.$contentType.'; charset='.get_pwg_charset());
     print_r($encodedResponse);
-    trigger_action('sendResponse', $encodedResponse );
+    trigger_notify('sendResponse', $encodedResponse );
   }
 
@@ -599,5 +599,5 @@
     }
     
-    $result = trigger_event('ws_invoke_allowed', true, $methodName, $params);
+    $result = trigger_change('ws_invoke_allowed', true, $methodName, $params);
     if ( strtolower( @get_class($result) )!='pwgerror')
     {
Index: /trunk/include/ws_functions/pwg.categories.php
===================================================================
--- /trunk/include/ws_functions/pwg.categories.php	(revision 28586)
+++ /trunk/include/ws_functions/pwg.categories.php	(revision 28587)
@@ -265,5 +265,5 @@
     {
       $row['name'] = strip_tags(
-        trigger_event(
+        trigger_change(
           'render_category_name',
           $row['name'],
@@ -274,5 +274,5 @@
 
     $row['comment'] = strip_tags(
-      trigger_event(
+      trigger_change(
         'render_category_description',
         $row['comment'],
@@ -502,5 +502,5 @@
 
     $row['name'] = strip_tags(
-      trigger_event(
+      trigger_change(
         'render_category_name',
         $row['name'],
@@ -515,5 +515,5 @@
       );
     $row['comment'] = strip_tags(
-      trigger_event(
+      trigger_change(
         'render_category_description',
         $row['comment'],
@@ -788,5 +788,5 @@
     {
       $row['name'] = strip_tags(
-        trigger_event(
+        trigger_change(
           'render_category_name',
           $row['name'],
Index: /trunk/index.php
===================================================================
--- /trunk/index.php	(revision 28586)
+++ /trunk/index.php	(revision 28587)
@@ -41,5 +41,5 @@
 }
 
-trigger_action('loc_begin_index');
+trigger_notify('loc_begin_index');
 
 //---------------------------------------------- change of image display order
@@ -362,5 +362,5 @@
 //------------------------------------------------------------ end
 include(PHPWG_ROOT_PATH.'include/page_header.php');
-trigger_action('loc_end_index');
+trigger_notify('loc_end_index');
 flush_page_messages();
 $template->parse_index_buttons();
Index: /trunk/nbm.php
===================================================================
--- /trunk/nbm.php	(revision 28586)
+++ /trunk/nbm.php	(revision 28587)
@@ -34,5 +34,5 @@
 load_language('admin.lang');
 // Need to update a second time
-trigger_action('loading_lang');
+trigger_notify('loading_lang');
 load_language('lang', PHPWG_ROOT_PATH.PWG_LOCAL_DIR, array('no_fallback'=>true, 'local'=>true) );
 
Index: /trunk/notification.php
===================================================================
--- /trunk/notification.php	(revision 28586)
+++ /trunk/notification.php	(revision 28587)
@@ -57,5 +57,5 @@
 check_status(ACCESS_GUEST);
 
-trigger_action('loc_begin_notification');
+trigger_notify('loc_begin_notification');
 
 // +-----------------------------------------------------------------------+
@@ -115,5 +115,5 @@
 // +-----------------------------------------------------------------------+
 include(PHPWG_ROOT_PATH.'include/page_header.php');
-trigger_action('loc_end_notification');
+trigger_notify('loc_end_notification');
 flush_page_messages();
 $template->pparse('notification');
Index: /trunk/password.php
===================================================================
--- /trunk/password.php	(revision 28586)
+++ /trunk/password.php	(revision 28587)
@@ -36,5 +36,5 @@
 check_status(ACCESS_FREE);
 
-trigger_action('loc_begin_password');
+trigger_notify('loc_begin_password');
 
 // +-----------------------------------------------------------------------+
@@ -118,5 +118,5 @@
   unset_make_full_url();
 
-  $message = trigger_event('render_lost_password_mail_content', $message);
+  $message = trigger_change('render_lost_password_mail_content', $message);
 
   $email_params = array(
@@ -354,5 +354,5 @@
 
 include(PHPWG_ROOT_PATH.'include/page_header.php');
-trigger_action('loc_end_password');
+trigger_notify('loc_end_password');
 flush_page_messages();
 $template->pparse('password');
Index: /trunk/picture.php
===================================================================
--- /trunk/picture.php	(revision 28586)
+++ /trunk/picture.php	(revision 28587)
@@ -145,5 +145,5 @@
 add_event_handler('render_element_description', 'nl2br');
 
-trigger_action('loc_begin_picture');
+trigger_notify('loc_begin_picture');
 
 // this is the default handler that generates the display for the element
@@ -435,5 +435,5 @@
 
 // don't increment if adding a comment
-if (trigger_event('allow_increment_element_hit_count', $inc_hit_count, $page['image_id'] ) )
+if (trigger_change('allow_increment_element_hit_count', $inc_hit_count, $page['image_id'] ) )
 {
   $query = '
@@ -615,5 +615,5 @@
 
 // do we have a plugin that can show metadata for something else than images?
-$metadata_showable = trigger_event(
+$metadata_showable = trigger_change(
   'get_element_metadata_available',
   (
@@ -633,5 +633,5 @@
 
 // allow plugins to change what we computed before passing data to template
-$picture = trigger_event('picture_pictures_data', $picture);
+$picture = trigger_change('picture_pictures_data', $picture);
 
 //------------------------------------------------------- navigation management
@@ -809,5 +809,5 @@
   $template->assign(
       'COMMENT_IMG',
-        trigger_event('render_element_description',
+        trigger_change('render_element_description',
           $picture['current']['comment'],
           'picture_page_element_description'
@@ -938,5 +938,5 @@
 // maybe someone wants a special display (call it before page_header so that
 // they can add stylesheets)
-$element_content = trigger_event(
+$element_content = trigger_change(
   'render_element_content',
   '',
@@ -988,5 +988,5 @@
 
 include(PHPWG_ROOT_PATH.'include/page_header.php');
-trigger_action('loc_end_picture');
+trigger_notify('loc_end_picture');
 flush_page_messages();
 if ($page['slideshow'] and $conf['light_slideshow'])
Index: /trunk/popuphelp.php
===================================================================
--- /trunk/popuphelp.php	(revision 28586)
+++ /trunk/popuphelp.php	(revision 28587)
@@ -55,5 +55,5 @@
   }
 
-  $help_content = trigger_event(
+  $help_content = trigger_change(
     'get_popup_help_content', $help_content, $_GET['page']);
 }
Index: /trunk/profile.php
===================================================================
--- /trunk/profile.php	(revision 28586)
+++ /trunk/profile.php	(revision 28587)
@@ -44,5 +44,5 @@
   $userdata = $user;
 
-  trigger_action('loc_begin_profile');
+  trigger_notify('loc_begin_profile');
 
 // Reset to default (Guest) custom settings
@@ -85,5 +85,5 @@
   
   include(PHPWG_ROOT_PATH.'include/page_header.php');
-  trigger_action('loc_end_profile');
+  trigger_notify('loc_end_profile');
   flush_page_messages();
   $template->pparse('profile');
@@ -280,5 +280,5 @@
                    array($data));
     }
-    trigger_action( 'save_profile_from_post', $userdata['id'] );
+    trigger_notify( 'save_profile_from_post', $userdata['id'] );
 
     if (!empty($_POST['redirect']))
@@ -336,5 +336,5 @@
 
   // allow plugins to add their own form data to content
-  trigger_action( 'load_profile_in_template', $userdata );
+  trigger_notify( 'load_profile_in_template', $userdata );
 
   $template->assign('PWG_TOKEN', get_pwg_token());
Index: /trunk/register.php
===================================================================
--- /trunk/register.php	(revision 28586)
+++ /trunk/register.php	(revision 28587)
@@ -38,5 +38,5 @@
 }
 
-trigger_action('loc_begin_register');
+trigger_notify('loc_begin_register');
 
 if (isset($_POST['submit']))
@@ -118,5 +118,5 @@
 
 include(PHPWG_ROOT_PATH.'include/page_header.php');
-trigger_action('loc_end_register');
+trigger_notify('loc_end_register');
 flush_page_messages();
 $template->parse('register');
Index: /trunk/search.php
===================================================================
--- /trunk/search.php	(revision 28586)
+++ /trunk/search.php	(revision 28587)
@@ -31,5 +31,5 @@
 check_status(ACCESS_GUEST);
 
-trigger_action('loc_begin_search');
+trigger_notify('loc_begin_search');
 
 //------------------------------------------------------------------ form check
@@ -237,5 +237,5 @@
 //------------------------------------------------------------ html code display
 include(PHPWG_ROOT_PATH.'include/page_header.php');
-trigger_action('loc_end_search');
+trigger_notify('loc_end_search');
 flush_page_messages();
 $template->pparse('search');
Index: /trunk/tags.php
===================================================================
--- /trunk/tags.php	(revision 28586)
+++ /trunk/tags.php	(revision 28587)
@@ -50,5 +50,5 @@
 check_status(ACCESS_GUEST);
 
-trigger_action('loc_begin_tags');
+trigger_notify('loc_begin_tags');
 
 // +-----------------------------------------------------------------------+
@@ -196,5 +196,5 @@
 
 include(PHPWG_ROOT_PATH.'include/page_header.php');
-trigger_action('loc_end_tags');
+trigger_notify('loc_end_tags');
 flush_page_messages();
 $template->pparse('tags');
Index: /trunk/tools/triggers_list.php
===================================================================
--- /trunk/tools/triggers_list.php	(revision 28586)
+++ /trunk/tools/triggers_list.php	(revision 28587)
@@ -3,5 +3,5 @@
 array(
   'name' => 'allow_increment_element_hit_count',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('bool', 'content_not_set'),
   'files' => array('picture.php'),
@@ -9,5 +9,5 @@
 array(
   'name' => 'begin_delete_elements',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('array', 'ids'),
   'files' => array('admin\include\functions.inc.php (delete_elements)'),
@@ -15,5 +15,5 @@
 array(
   'name' => 'blockmanager_apply',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('object', 'menublock'),
   'files' => array('include\block.class.php (BlockManager::apply)'),
@@ -22,5 +22,5 @@
 array(
   'name' => 'blockmanager_prepare_display',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('object', 'this'),
   'files' => array('include\block.class.php (BlockManager::prepare_display)'),
@@ -28,5 +28,5 @@
 array(
   'name' => 'blockmanager_register_blocks',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('object', 'menu'),
   'files' => array('include\block.class.php (BlockManager::load_registered_blocks)'),
@@ -35,5 +35,5 @@
 array(
   'name' => 'clean_iptc_value',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'value'),
   'files' => array('include\functions_metadata.inc.php (clean_iptc_value)'),
@@ -41,5 +41,5 @@
 array(
   'name' => 'combined_css',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'href', 'Combinable', '$combinable'),
   'files' => array('include\template.class.php (Template::flush)'),
@@ -47,5 +47,5 @@
 array(
   'name' => 'combined_css_postfilter',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'css'),
   'files' => array('include\template.class.php (Template::process_css)'),
@@ -53,5 +53,5 @@
 array(
   'name' => 'combined_script',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'ret', 'string', 'script'),
   'files' => array('include\template.class.php (Template::make_script_src)'),
@@ -59,5 +59,5 @@
 array(
   'name' => 'delete_categories',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('array', 'ids'),
   'files' => array('admin\include\functions.inc.php (delete_categories)'),
@@ -65,5 +65,5 @@
 array(
   'name' => 'delete_elements',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('array', 'ids'),
   'files' => array('admin\include\functions.inc.php (delete_elements)'),
@@ -71,5 +71,5 @@
 array(
   'name' => 'delete_user',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('int', 'user_id'),
   'files' => array('admin\include\functions.inc.php (delete_user)'),
@@ -77,5 +77,5 @@
 array(
   'name' => 'element_set_global_action',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('string', 'action', 'array', 'collection'),
   'files' => array('admin\batch_manager_global.php'),
@@ -83,5 +83,5 @@
 array(
   'name' => 'format_exif_data',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'exif', 'string', 'filename', 'array', 'map'),
   'files' => array('include\functions_metadata.inc.php (get_exif_data)'),
@@ -89,5 +89,5 @@
 array(
   'name' => 'functions_history_included',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\include\functions_history.inc.php'),
@@ -95,5 +95,5 @@
 array(
   'name' => 'functions_mail_included',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\functions_mail.inc.php'),
@@ -101,5 +101,5 @@
 array(
   'name' => 'get_admin_advanced_features_links',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'advanced_features'),
   'files' => array('admin\maintenance.php'),
@@ -107,5 +107,5 @@
 array(
   'name' => 'get_admin_plugin_menu_links',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', null),
   'files' => array('admin.php'),
@@ -114,5 +114,5 @@
 array(
   'name' => 'get_admins_site_links',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'plugin_links', 'int', 'site_id', 'bool', 'is_remote'),
   'files' => array('admin\site_manager.php'),
@@ -120,5 +120,5 @@
 array(
   'name' => 'get_batch_manager_prefilters',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'prefilters'),
   'files' => array('admin\batch_manager_global.php'),
@@ -127,5 +127,5 @@
 array(
   'name' => 'get_categories_menu_sql_where',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'where', 'bool', 'user_expand', 'bool', 'filter_enabled'),
   'files' => array('include\functions_category.inc.php (get_categories_menu)'),
@@ -133,5 +133,5 @@
 array(
   'name' => 'get_category_preferred_image_orders',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', null),
   'files' => array('include\functions_category.inc.php (get_category_preferred_image_orders)'),
@@ -139,5 +139,5 @@
 array(
   'name' => 'get_download_url',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'url', 'array', 'element_info'),
   'files' => array('include\functions_picture.inc.php (get_download_url)'),
@@ -145,5 +145,5 @@
 array(
   'name' => 'get_element_metadata_available',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('bool', null, 'string', 'element_path'),
   'files' => array('picture.php'),
@@ -151,5 +151,5 @@
 array(
   'name' => 'get_element_url',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'url', 'array', 'element_info'),
   'files' => array('include\functions_picture.inc.php (get_element_url)'),
@@ -157,5 +157,5 @@
 array(
   'name' => 'get_high_location',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'location', 'array', 'element_info'),
   'files' => array('include\functions_picture.inc.php (get_high_location)'),
@@ -163,5 +163,5 @@
 array(
   'name' => 'get_high_url',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'url', 'array', 'element_info'),
   'files' => array('include\functions_picture.inc.php (get_high_url)'),
@@ -169,5 +169,5 @@
 array(
   'name' => 'get_history',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', null, 'array', 'page_search', 'array', 'types'),
   'files' => array('admin\history.php'),
@@ -175,5 +175,5 @@
 array(
   'name' => 'get_image_location',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'path', 'array', 'element_info'),
   'files' => array('include\functions_picture.inc.php (get_image_location)'),
@@ -181,5 +181,5 @@
 array(
   'name' => 'get_popup_help_content',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'help_content', 'string', 'page'),
   'files' => array('admin\popuphelp.php', 'popuphelp.php'),
@@ -187,5 +187,5 @@
 array(
   'name' => 'get_pwg_themes',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'themes'),
   'files' => array('include\functions.inc.php (get_pwg_themes)'),
@@ -193,5 +193,5 @@
 array(
   'name' => 'get_thumbnail_title',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'title', 'array', 'info'),
   'files' => array('include\functions.inc.php (get_thumbnail_title)'),
@@ -199,5 +199,5 @@
 array(
   'name' => 'get_comments_derivative_params',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('ImageStdParams', null),
   'files' => array('comments.php'),
@@ -206,5 +206,5 @@
 array(
   'name' => 'get_index_album_derivative_params',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('ImageStdParams', null),
   'files' => array('includecategory_cats.php', 'include\category_default.inc.php'),
@@ -213,5 +213,5 @@
 array(
   'name' => 'get_src_image_url',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'url', 'SrcImage', 'this'),
   'files' => array('include\derivative.inc.php (SrcImage::__construct)'),
@@ -220,5 +220,5 @@
 array(
   'name' => 'get_derivative_url',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'url', 'ImageStdParams', null, 'SrcImage', 'this', 'string', 'rel_url'),
   'files' => array('include\derivative.inc.php (SrcImage::url, SrcImage::get_url)'),
@@ -227,5 +227,5 @@
 array(
   'name' => 'get_tag_alt_names',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', null, 'array', 'raw_name'),
   'files' => array('admin\tags.php', 'admin\include\functions.php (get_taglist)'),
@@ -234,5 +234,5 @@
 array(
   'name' => 'get_webmaster_mail_address',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'email'),
   'files' => array('include\functions.inc.php (get_webmaster_mail_address)'),
@@ -241,5 +241,5 @@
 array(
   'name' => 'init',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\common.inc.php'),
@@ -248,5 +248,5 @@
 array(
   'name' => 'invalidate_user_cache',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('bool', 'full'),
   'files' => array('admin\include\functions.inc.php (invalidate_user_cache)'),
@@ -254,5 +254,5 @@
 array(
   'name' => 'load_conf',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('string', 'condition'),
   'files' => array('include\functions.inc.php (load_conf_from_db)'),
@@ -261,5 +261,5 @@
 array(
   'name' => 'list_check_integrity',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('object', 'this'),
   'files' => array('admin\include\check_integrity.class.php (check_integrity::check)'),
@@ -267,5 +267,5 @@
 array(
   'name' => 'load_image_library',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('object', 'this'),
   'files' => array('admin\include\image.class.php (pwg_image::__construct)'),
@@ -273,5 +273,5 @@
 array(
   'name' => 'load_profile_in_template',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('array', 'userdata'),
   'files' => array('profile.php (load_profile_in_template)'),
@@ -279,5 +279,5 @@
 array(
   'name' => 'loading_lang',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\common.inc.php', 'include\functions.inc.php (redirect_html)', 'include\functions_mail.inc.php (switch_lang_to)', 'nbm.php'),
@@ -285,5 +285,5 @@
 array(
   'name' => 'loc_after_page_header',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\page_header.php'),
@@ -291,5 +291,5 @@
 array(
   'name' => 'loc_begin_about',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('about.php'),
@@ -297,5 +297,5 @@
 array(
   'name' => 'loc_begin_admin',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin.php'),
@@ -303,5 +303,5 @@
 array(
   'name' => 'loc_begin_admin_page',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin.php'),
@@ -309,5 +309,5 @@
 array(
   'name' => 'loc_begin_cat_list',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\cat_list.php'),
@@ -315,5 +315,5 @@
 array(
   'name' => 'loc_begin_cat_modify',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\cat_modify.php'),
@@ -321,5 +321,5 @@
 array(
   'name' => 'loc_begin_element_set_global',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\batch_manager_global.php'),
@@ -327,5 +327,5 @@
 array(
   'name' => 'loc_begin_element_set_unit',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\batch_manager_unit.php'),
@@ -333,5 +333,5 @@
 array(
   'name' => 'loc_begin_index',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('index.php'),
@@ -339,5 +339,5 @@
 array(
   'name' => 'loc_begin_index_category_thumbnails',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('array', 'categories'),
   'files' => array('include\category_cats.inc.php'),
@@ -345,5 +345,5 @@
 array(
   'name' => 'loc_begin_index_thumbnails',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('array', 'pictures'),
   'files' => array('include\category_default.inc.php'),
@@ -351,5 +351,5 @@
 array(
   'name' => 'loc_begin_page_header',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\page_header.php'),
@@ -357,5 +357,5 @@
 array(
   'name' => 'loc_begin_page_tail',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\page_tail.php'),
@@ -363,5 +363,5 @@
 array(
   'name' => 'loc_begin_picture',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('picture.php'),
@@ -369,5 +369,5 @@
 array(
   'name' => 'loc_begin_profile',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('profile.php'),
@@ -375,5 +375,5 @@
 array(
   'name' => 'loc_begin_password',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('password.php'),
@@ -382,5 +382,5 @@
 array(
   'name' => 'loc_begin_register',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('register.php'),
@@ -389,5 +389,5 @@
 array(
   'name' => 'loc_begin_search',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('search.php'),
@@ -396,5 +396,5 @@
 array(
   'name' => 'loc_begin_tags',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('tags.php'),
@@ -403,5 +403,5 @@
 array(
   'name' => 'loc_begin_comments',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('comments.php'),
@@ -410,5 +410,5 @@
 array(
   'name' => 'loc_begin_identification',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('identification.php'),
@@ -417,5 +417,5 @@
 array(
   'name' => 'loc_begin_notification',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('notification.php'),
@@ -424,5 +424,5 @@
 array(
   'name' => 'loc_end_password',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('password.php'),
@@ -431,5 +431,5 @@
 array(
   'name' => 'loc_end_register',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('register.php'),
@@ -438,5 +438,5 @@
 array(
   'name' => 'loc_end_search',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('search.php'),
@@ -445,5 +445,5 @@
 array(
   'name' => 'loc_end_tags',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('tags.php'),
@@ -452,5 +452,5 @@
 array(
   'name' => 'loc_end_comments',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('comments.php'),
@@ -459,5 +459,5 @@
 array(
   'name' => 'loc_end_identification',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('identification.php'),
@@ -466,5 +466,5 @@
 array(
   'name' => 'loc_end_notification',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('notification.php'),
@@ -473,5 +473,5 @@
 array(
   'name' => 'loc_end_admin',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin.php'),
@@ -479,5 +479,5 @@
 array(
   'name' => 'loc_end_cat_list',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\cat_list.php'),
@@ -485,5 +485,5 @@
 array(
   'name' => 'loc_end_cat_modify',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\cat_modify.php'),
@@ -491,5 +491,5 @@
 array(
   'name' => 'loc_end_element_set_global',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\batch_manager_global.php'),
@@ -497,5 +497,5 @@
 array(
   'name' => 'loc_end_element_set_unit',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\batch_manager_unit.php'),
@@ -503,5 +503,5 @@
 array(
   'name' => 'loc_end_help',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\help.php'),
@@ -509,5 +509,5 @@
 array(
   'name' => 'loc_end_index',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('index.php'),
@@ -515,5 +515,5 @@
 array(
   'name' => 'loc_end_index_category_thumbnails',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'tpl_thumbnails_var'),
   'files' => array('include\category_cats.inc.php'),
@@ -521,5 +521,5 @@
 array(
   'name' => 'loc_end_index_thumbnails',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'tpl_thumbnails_var', 'array', 'pictures'),
   'files' => array('include\category_default.inc.php'),
@@ -527,5 +527,5 @@
 array(
   'name' => 'loc_end_no_photo_yet',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\no_photo_yet.inc.php'),
@@ -533,5 +533,5 @@
 array(
   'name' => 'loc_end_page_header',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\page_header.php'),
@@ -539,5 +539,5 @@
 array(
   'name' => 'loc_end_page_tail',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\page_tail.php'),
@@ -545,5 +545,5 @@
 array(
   'name' => 'loc_end_picture',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('picture.php'),
@@ -551,5 +551,5 @@
 array(
   'name' => 'loc_end_picture_modify',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\picture_modify.php'),
@@ -558,5 +558,5 @@
 array(
   'name' => 'loc_end_profile',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('profile.php'),
@@ -564,5 +564,5 @@
 array(
   'name' => 'loc_end_section_init',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\section_init.inc.php'),
@@ -571,5 +571,5 @@
 array(
   'name' => 'loc_end_themes_installed',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\themes_installed.php'),
@@ -578,5 +578,5 @@
 array(
   'name' => 'loc_visible_user_list',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'visible_user_list'),
   'files' => array('admin\user_list.php'),
@@ -584,5 +584,5 @@
 array(
   'name' => 'login_failure',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('string', 'username'),
   'files' => array('include\functions_user.inc.php (try_log_user)'),
@@ -590,5 +590,5 @@
 array(
   'name' => 'login_success',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('string', 'username'),
   'files' => array('include\functions_user.inc.php (auto_login, try_log_user)'),
@@ -596,5 +596,5 @@
 array(
   'name' => 'nbm_event_handler_added',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('admin\notification_by_mail.php'),
@@ -602,5 +602,5 @@
 array(
   'name' => 'nbm_render_global_customize_mail_content',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'customize_mail_content'),
   'files' => array('admin\notification_by_mail.php (do_action_send_mail_notification)'),
@@ -608,5 +608,5 @@
 array(
   'name' => 'nbm_render_user_customize_mail_content',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'customize_mail_content', 'string', 'nbm_user'),
   'files' => array('admin\notification_by_mail.php (do_action_send_mail_notification)'),
@@ -614,5 +614,5 @@
 array(
   'name' => 'perform_batch_manager_prefilters',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'filter_sets', 'string', 'session_prefilter'),
   'files' => array('admin\batch_manager.php'),
@@ -620,5 +620,5 @@
 array(
   'name' => 'picture_pictures_data',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'picture'),
   'files' => array('picture.php'),
@@ -626,5 +626,5 @@
 array(
   'name' => 'plugins_loaded',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array(),
   'files' => array('include\functions_plugins.inc.php (load_plugins)'),
@@ -632,5 +632,5 @@
 array(
   'name' => 'pwg_log_allowed',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('bool', 'do_log', 'int', 'image_id', 'string', 'image_type'),
   'files' => array('include\functions.inc.php (pwg_log)'),
@@ -638,5 +638,5 @@
 array(
   'name' => 'register_user',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('array', 'user'),
   'files' => array('include\functions_user.inc.php (register_user)'),
@@ -644,5 +644,5 @@
 array(
   'name' => 'register_user_check',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'errors', 'array', 'user'),
   'files' => array('include\functions_user.inc.php (register_user)'),
@@ -650,5 +650,5 @@
 array(
   'name' => 'render_category_description',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'category_description', 'string', 'action'),
   'files' => array('include\category_cats.inc.php', 'include\section_init.inc.php', 'include\ws_functions.inc.php (ws_categories_getList, ws_categories_getAdminList)'),
@@ -656,5 +656,5 @@
 array(
   'name' => 'render_category_literal_description',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'category_description'),
   'files' => array('include\category_cats.inc.php'),
@@ -662,5 +662,5 @@
 array(
   'name' => 'render_category_name',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'category_name', 'string', 'location'),
   'files' => array('admin\cat_list.php', 'include\ws_functions.inc.php (ws_categories_getList, ws_categories_getAdminList, ws_categories_move)'),
@@ -668,5 +668,5 @@
 array(
   'name' => 'render_comment_author',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'comment_author'),
   'files' => array('admin\comments.php', 'comments.php', 'include\picture_comment.inc.php'),
@@ -674,5 +674,5 @@
 array(
   'name' => 'render_comment_content',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'comment_content'),
   'files' => array('admin\comments.php', 'comments.php', 'include\picture_comment.inc.php'),
@@ -680,5 +680,5 @@
 array(
   'name' => 'render_element_content',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'content', 'array', 'current_picture'),
   'files' => array('picture.php'),
@@ -686,5 +686,5 @@
 array(
   'name' => 'render_element_name',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'element_name'),
   'files' => array('include\functions_html.inc.php (render_element_name)'),
@@ -692,5 +692,5 @@
 array(
   'name' => 'render_element_description',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'element_description', 'string', 'action'),
   'files' => array('picture.php', 'include\functions_html.inc.php (render_element_description)'),
@@ -698,5 +698,5 @@
 array(
   'name' => 'render_lost_password_mail_content',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'message'),
   'files' => array('password.php (process_password_request)'),
@@ -704,5 +704,5 @@
 array(
   'name' => 'render_page_banner',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'gallery_title'),
   'files' => array('include\page_header.php'),
@@ -710,5 +710,5 @@
 array(
   'name' => 'render_tag_name',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'tag_name', 'array', 'tag'),
   'files' => array('admin\include\functions.php (get_taglist)', 'admin\tags.php', 'admin\history.php', 'include\functions_tag.inc.php (get_available_tags, get_all_tags, get_common_tags)', 'include\functions_html.inc.php (get_tags_content_title)', 'include\functions_search.inc.php (get_qsearch_tags)'),
@@ -716,5 +716,5 @@
 array(
   'name' => 'render_tag_url',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'tag_name'),
   'files' => array('admin\include\functions.php (tag_id_from_tag_name, create_tag)', 'admin\tags.php'),
@@ -722,5 +722,5 @@
 array(
   'name' => 'save_profile_from_post',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('int', 'user_id'),
   'files' => array('profile.php (save_profile_from_post)'),
@@ -728,5 +728,5 @@
 array(
   'name' => 'before_send_mail',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('bool', 'result', 'mixed', 'to', 'array', 'arguments', 'PHPMailer', 'mail'),
   'files' => array('include\functions_mail.inc.php (pwg_mail)'),
@@ -734,5 +734,5 @@
 array(
   'name' => 'before_parse_mail_template',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('string', 'cache_key', 'string', 'content_type'),
   'files' => array('include\functions_mail.inc.php (pwg_mail)'),
@@ -740,5 +740,5 @@
 array(
   'name' => 'sendResponse',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('string', 'encodedResponse'),
   'files' => array('include\ws_core.inc.php (PwgServer::sendResponse)'),
@@ -746,5 +746,5 @@
 array(
   'name' => 'set_status_header',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('int', 'code', 'string', 'text'),
   'files' => array('include\functions_html.inc.php (set_status_header)'),
@@ -752,5 +752,5 @@
 array(
   'name' => 'tabsheet_before_select',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'sheets', 'string', 'tabsheet_id'),
   'files' => array('include\tabsheet.class.php (tabsheet::select)'),
@@ -759,11 +759,11 @@
 array(
   'name' => 'trigger',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('array', null),
-  'files' => array('include\functions_plugins.inc.php (trigger_event, trigger_action)'),
+  'files' => array('include\functions_plugins.inc.php (trigger_change, trigger_notify)'),
 ),
 array(
   'name' => 'user_comment_check',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string', 'comment_action', 'array', 'comm'),
   'files' => array('include\functions_comment.inc.php (insert_user_comment, update_user_comment)'),
@@ -772,5 +772,5 @@
 array(
   'name' => 'user_comment_deletion',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('mixed', 'comment_id'),
   'files' => array('include\functions_comment.inc.php (delete_user_comment)'),
@@ -779,5 +779,5 @@
 array(
   'name' => 'user_comment_insertion',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('array', 'comm'),
   'files' => array('include\picture_comment.inc.php'),
@@ -785,5 +785,5 @@
 array(
   'name' => 'user_comment_validation',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('mixed', 'comment_id'),
   'files' => array('include\functions_comment.inc.php (validate_user_comment)'),
@@ -792,5 +792,5 @@
 array(
   'name' => 'user_init',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('array', 'user'),
   'files' => array('include\user.inc.php'),
@@ -798,5 +798,5 @@
 array(
   'name' => 'ws_add_methods',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('object', 'this'),
   'files' => array('include\ws_core.inc.php (PwgServer::run)'),
@@ -804,5 +804,5 @@
 array(
   'name' => 'ws_invoke_allowed',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('bool', null, 'string', 'methodName', 'array', 'params'),
   'files' => array('include\ws_core.inc.php (PwgServer::invoke)'),
@@ -810,5 +810,5 @@
 array(
   'name' => 'user_logout',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('int', 'user_id'),
   'files' => array('include\functions_user.inc.php (logout_user)'),
@@ -817,5 +817,5 @@
 array(
   'name' => 'user_login',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('int', 'user_id'),
   'files' => array('include\functions_user.inc.php (log_user)'),
@@ -824,5 +824,5 @@
 array(
   'name' => 'try_log_user',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('boolean', 'success', 'string', 'username', 'string', 'password', 'bool', 'remember_me'),
   'files' => array('include\functions_user.inc.php (try_log_user)'),
@@ -831,5 +831,5 @@
 array(
   'name' => 'combinable_preparse',
-  'type' => 'trigger_action',
+  'type' => 'trigger_notify',
   'vars' => array('Template', 'template', 'Combinable', '$combinable', 'FileCombiner', '$combiner'),
   'files' => array('include\template.class.php (FileCombiner::process_combinable)'),
@@ -838,5 +838,5 @@
 array(
   'name' => 'user_list_columns',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('string[]', 'aColumns'),
   'files' => array('admin\user_list_backend.php'),
@@ -845,5 +845,5 @@
 array(
   'name' => 'after_render_user_list',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'output'),
   'files' => array('admin\user_list_backend.php'),
@@ -852,5 +852,5 @@
 array(
   'name' => 'update_rating_score',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('boolean', 'done', 'int', 'element_id'),
   'files' => array('include\functions_rate.inc.php'),
@@ -859,5 +859,5 @@
 array(
   'name' => 'picture_modify_before_update',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'data'),
   'files' => array('admin\picture_modify.php'),
@@ -866,5 +866,5 @@
 array(
   'name' => 'ws_users_getList',
-  'type' => 'trigger_event',
+  'type' => 'trigger_change',
   'vars' => array('array', 'users'),
   'files' => array('include\ws_functions\pwg.users.php'),
@@ -974,6 +974,6 @@
         <select class="search_input">
           <option value="">Type</option>
-          <option value="trigger_action">trigger_action</option>
-          <option value="trigger_event">trigger_event</option>
+          <option value="trigger_notify">trigger_notify</option>
+          <option value="trigger_change">trigger_change</option>
         </select>
       </td>

Index: /trunk/include/functions_comment.inc.php
===================================================================
--- /trunk/include/functions_comment.inc.php	(revision 28586)
+++ /trunk/include/functions_comment.inc.php	(revision 28587)
@@ -32,5 +32,5 @@
 /**
  * Does basic check on comment and returns action to perform.
  * This method is called by a trigger_event()
  *
  * @param string $action before check
@@ -212,5 +212,5 @@
 
   // perform more spam check
-  $comment_action = trigger_event('user_comment_check',
+  $comment_action = trigger_change('user_comment_check',
       $comment_action, $comm
     );
@@ -304,5 +304,5 @@
                       'comment_id' => $comment_id
                   ));
-    trigger_action('user_comment_deletion', $comment_id);
+    trigger_notify('user_comment_deletion', $comment_id);
 
     return true;
@@ -343,5 +343,5 @@
   // perform more spam check
   $comment_action =
-    trigger_event('user_comment_check',
+    trigger_change('user_comment_check',
 		  $comment_action,
 		  array_merge($comment,
@@ -510,5 +510,5 @@
   
   invalidate_user_cache_nb_comments();
-  trigger_action('user_comment_validation', $comment_id);
+  trigger_notify('user_comment_validation', $comment_id);
 }
 
@@ -32,5 +32,5 @@
 /**
  * Does basic check on comment and returns action to perform.
- * This method is called by a trigger_event()
+ * This method is called by a trigger_change()
  *
  * @param string $action before check
Index: /trunk/include/functions_html.inc.php
===================================================================
--- /trunk/include/functions_html.inc.php	(revision 28586)
+++ /trunk/include/functions_html.inc.php	(revision 28587)
@@ -52,5 +52,5 @@
       );
 
-    $cat['name'] = trigger_event(
+    $cat['name'] = trigger_change(
       'render_category_name',
       $cat['name'],
@@ -133,5 +133,5 @@
     $cat = $cache['cat_names'][$category_id];
 
-    $cat['name'] = trigger_event(
+    $cat['name'] = trigger_change(
       'render_category_name',
       $cat['name'],
@@ -464,5 +464,5 @@
       .l10n('display photos linked to this tag')
       .'">'
-      .trigger_event('render_tag_name', $page['tags'][$i]['name'], $page['tags'][$i])
+      .trigger_change('render_tag_name', $page['tags'][$i]['name'], $page['tags'][$i])
       .'</a>';
 
@@ -518,10 +518,10 @@
 
   header( "$protocol $code $text", true, $code );
-  trigger_action('set_status_header', $code, $text);
+  trigger_notify('set_status_header', $code, $text);
 }
 
 /**
  * Returns the category comment for rendering in html textual mode (subcatify)
  * This method is called by a trigger_action()
  *
  * @param string $desc
@@ -535,5 +535,5 @@
 /**
  * Add known menubar blocks.
  * This method is called by a trigger_event()
  *
  * @param BlockManager[] $menu_ref_arr
@@ -563,5 +563,5 @@
   if (!empty($info['name']))
   {
-    return trigger_event('render_element_name', $info['name']);
+    return trigger_change('render_element_name', $info['name']);
   }
   return get_name_from_file($info['file']);
@@ -579,5 +579,5 @@
   if (!empty($info['comment']))
   {
-    return trigger_event('render_element_description', $info['comment'], $param);
+    return trigger_change('render_element_description', $info['comment'], $param);
   }
   return '';
@@ -625,5 +625,5 @@
 
   $title = htmlspecialchars(strip_tags($title));
-  $title = trigger_event('get_thumbnail_title', $title, $info);
+  $title = trigger_change('get_thumbnail_title', $title, $info);
 
   return $title;
@@ -518,10 +518,10 @@
 /**
  * Returns the category comment for rendering in html textual mode (subcatify)
- * This method is called by a trigger_action()
+ * This method is called by a trigger_notify()
  *
  * @param string $desc
@@ -535,5 +535,5 @@
 /**
  * Add known menubar blocks.
- * This method is called by a trigger_event()
+ * This method is called by a trigger_change()
  *
  * @param BlockManager[] $menu_ref_arr